==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InsertBlockItem</name>
    <message>
        <location filename="../InsertBlockItem.js" line="+88"/>
        <source>Cannot import file from URL: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Skorygowany nieprawidłową nazwę bloku do&apos;&amp;#39;</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="unfinished">Położenie</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obracanie:</translatorcomment>
        <translation type="unfinished">Obracanie:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Obróć wklejone podmioty &lt;br&gt; przez to kąt</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation type="unfinished">Skala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Skala wklejone podmioty &lt;br&gt; tym czynnikiem</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przerzuć wklejone podmioty &lt;br&gt; poziomo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przerzuć wklejone podmioty &lt;br&gt; pionowo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp istniejące warstwy &lt;br&gt; w rysowanie &lt;br&gt; warstwy ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp warstw</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp istniejące bloki &lt;br&gt; w rysowanie &lt;br&gt; bloki z schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp bloki</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wstaw blok</translatorcomment>
        <translation type="unfinished">&amp;Wstaw blok</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/InsertBlockItem/ts/InsertBlockItem_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InsertBlockItem</name>
    <message>
        <location filename="../InsertBlockItem.js" line="+102"/>
        <source>Cannot import file from URL: </source>
        <translation>Nie można zaimportować pliku z adresu URL:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Adjusted invalid block name to &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zmieniono nieprawidłową nazwę bloku na „%1”</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../InsertBlockItem.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obracanie:</translatorcomment>
        <translation>Obrót:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Obraca wklejone obiekty o zadany kąt</translation>
    </message>
    <message>
        <location line="+100"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation>Skala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Skaluje wklejone obiekty przez zadany współczynnik</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odbija lustrzanie wklejone obiekty poziomo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odbij lustrzanie wklejone obiekty pionowo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastępuje istniejące warstwy rysunku warstwami ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąp warstwy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastępuje istniejące bloki rysunku blokami ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąp bloki</translation>
    </message>
    <message>
        <location filename="../InsertBlockItemInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wstaw blok</translatorcomment>
        <translation>&amp;Wstaw blok</translation>
    </message>
</context>
</TS>
